@@ -1,5 +1,10 @@
 """a wrapper for memuc.exe as a library to control virual machines"""
-from .exceptions import PyMemucError, PyMemucIndexError, PyMemucTimeoutExpired
+from .exceptions import (
+    PyMemucError,
+    PyMemucException,
+    PyMemucIndexError,
+    PyMemucTimeoutExpired,
+)
 from .pymemuc import PyMemuc
 from .vminfo import VMInfo
 
@@ -9,4 +14,5 @@ __all__ = [
     "PyMemucError",
     "PyMemucIndexError",
     "PyMemucTimeoutExpired",
+    "PyMemucException",
 ]
