@@ -1,5 +1,7 @@
 """This module contains decorators for functions in pymemuc."""
 
+from functools import wraps
+
 from ._constants import RETRIES
 from .exceptions import PyMemucError, PyMemucTimeoutExpired
 
@@ -10,6 +12,7 @@ def _retryable(func):
     After the last retry, the exception is raised.
     """
 
+    @wraps(func)
     def wrapper(self, *args, **kwargs):
         fin_err = None  # track the last error
         for i in range(RETRIES):
@@ -18,7 +21,7 @@ def _retryable(func):
             except (PyMemucError, PyMemucTimeoutExpired) as err:
                 fin_err = err  # update the last error
                 if self.debug:
-                    print(f"pymemuc._memuc.retryable: {err}")
+                    print(f"pymemuc._decorators._retryable: {err}")
                     r_left = RETRIES - i - 1
                     if r_left > 0:
                         print(
