@@ -35,7 +35,9 @@ def create_vm(self: "PyMemuc", vm_version="76") -> int:
 
 
 @_retryable
-def delete_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
+def delete_vm(
+    self: "PyMemuc", vm_index: int | None = None, vm_name: str | None = None
+) -> Literal[True]:
     """Delete a VM, must specify either a vm index or a vm name
 
     :param vm_index: VM index. Defaults to None.
@@ -59,7 +61,10 @@ def delete_vm(self: "PyMemuc", vm_index=None, vm_name=None) -> Literal[True]:
 
 
 def clone_vm(
-    self: "PyMemuc", vm_index=None, vm_name=None, new_name=None
+    self: "PyMemuc",
+    vm_index: int | None = None,
+    vm_name: str | None = None,
+    new_name=None,
 ) -> Literal[True]:
     """Clone a VM, must specify either a vm index or a vm name
 
@@ -88,7 +93,11 @@ def clone_vm(
 
 # TODO: verify functionality
 def export_vm(
-    self: "PyMemuc", vm_index=None, vm_name=None, file_name="vm.ova", non_blocking=False
+    self: "PyMemuc",
+    vm_index: int | None = None,
+    vm_name: str | None = None,
+    file_name="vm.ova",
+    non_blocking=False,
 ):
     """Export a VM, must specify either a vm index or a vm name
 
@@ -134,7 +143,10 @@ def import_vm(self: "PyMemuc", file_name="vm.ova", non_blocking=False) -> Litera
 
 @_retryable
 def rename_vm(
-    self: "PyMemuc", vm_index=None, vm_name=None, new_name=None
+    self: "PyMemuc",
+    vm_index: int | None = None,
+    vm_name: str | None = None,
+    new_name=None,
 ) -> Literal[True]:
     """Rename a VM, must specify either a vm index or a vm name
 
@@ -169,7 +181,11 @@ def rename_vm(
 
 
 def list_vm_info(
-    self: "PyMemuc", vm_index=None, vm_name=None, running=False, disk_info=False
+    self: "PyMemuc",
+    vm_index: int | None = None,
+    vm_name: str | None = None,
+    running=False,
+    disk_info=False,
 ) -> list[VMInfo]:
     """List VM info, must specify either a vm index or a vm name
 
@@ -217,6 +233,11 @@ def list_vm_info(
             ["listvms", "-r" if running else "", "-s" if disk_info else ""]
         )
 
+    # handle when no VMs are on the system
+    # memuc.exe will output a "read failed" error
+    if "read failed" in output:
+        return []
+
     output = output.split("\n")
     parsed_output = []
 
@@ -252,11 +273,12 @@ def vm_is_running(self: "PyMemuc", vm_index=0) -> bool:
 
 
 def get_configuration_vm(
-    self: "PyMemuc", config_key, vm_index=None, vm_name=None
+    self: "PyMemuc", config_key, vm_index: int | None = None, vm_name: str | None = None
 ) -> str:
     """Get a VM configuration, must specify either a vm index or a vm name
 
-    :param config_key: Configuration key, keys are noted in `configuration keys table <https://pymemuc.readthedocs.io/pymemuc.html#the-vm-configuration-keys-table>`_
+    :param config_key: Configuration key, keys are noted in `configuration keys table
+        <https://pymemuc.readthedocs.io/pymemuc.html#the-vm-configuration-keys-table>`_
     :type config_key: str
     :param vm_index: VM index. Defaults to None.
     :type vm_index: int, optional
@@ -281,11 +303,16 @@ def get_configuration_vm(
 
 
 def set_configuration_vm(
-    self: "PyMemuc", config_key: str, config_value: str, vm_index=None, vm_name=None
+    self: "PyMemuc",
+    config_key: str,
+    config_value: str,
+    vm_index: int | None = None,
+    vm_name: str | None = None,
 ) -> Literal[True]:
     """Set a VM configuration, must specify either a vm index or a vm name
 
-    :param config_key: Configuration key, keys are noted in `configuration keys table <https://pymemuc.readthedocs.io/pymemuc.html#the-vm-configuration-keys-table>`_
+    :param config_key: Configuration key, keys are noted in `configuration keys table
+        <https://pymemuc.readthedocs.io/pymemuc.html#the-vm-configuration-keys-table>`_
     :type config_key: str
     :param config_value: Configuration value
     :type config_value: str
